@@ -360,7 +360,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 				if (qso[LOCATOR] && (strlen(qso[LOCATOR]) > 0))
 				{
 					loc_new_qso(qso[LOCATOR], f, qslconfirmed);
-					if ((preferences.awardsloc == 1))
+					if (preferences.awardsloc == 1)
 						update_locscoring ();
 				}
 			}
@@ -374,7 +374,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 					gboolean qslconfirmed = qslreceived (qso[QSLIN]);
 					f = freq2enum (qso[BAND]);
 					loc_new_qso(qso[LOCATOR], f, qslconfirmed);
-					if ((preferences.awardsloc == 1))
+					if (preferences.awardsloc == 1)
 						update_locscoring ();
 				}
 			}
@@ -608,7 +608,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 					if (locator && (strlen(locator) > 0))
 					{
 						loc_del_qso(locator, f, qslin);
-						if ((preferences.awardsloc == 1))
+						if (preferences.awardsloc == 1)
 							update_locscoring ();
 					}
 				}
@@ -622,7 +622,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 						gboolean qslconfirmed = qslreceived (qso[QSLIN]);
 						f = freq2enum (qso[BAND]);
 						loc_new_qso(qso[LOCATOR], f, qslconfirmed);
-						if ((preferences.awardsloc == 1))
+						if (preferences.awardsloc == 1)
 							update_locscoring ();
 					}
 				}
@@ -1050,7 +1050,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 						fr = freq2enum (qso[BAND]);
 						qslconfirmed = qslreceived (qso[QSLIN]);
 						loc_new_qso(qso[LOCATOR], fr, qslconfirmed);
-						if ((preferences.awardsloc == 1))
+						if (preferences.awardsloc == 1)
 							update_locscoring ();
 					}
 				}
